<?php

use App\Kernel;
use Symfony\Component\Debug\Debug;
use Symfony\Component\Dotenv\Dotenv;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\RedirectResponse;
use \Homegear\Homegear as Homegear;

#define("HGS", true);
define("UIVERSION", "%%UIVERSION%%");

ini_set('session.name', 'PHPSESSIDADMIN');

require __DIR__.'/../vendor/autoload.php';

$hg = new Homegear();
$appEnv = $hg->getData('webEnv', 'env');
if ($appEnv) {
    $_SERVER['APP_ENV'] = $appEnv;
}

// The check is to ensure we don't use .env in production
if (!isset($_SERVER['APP_ENV'])) {
    if (!class_exists(Dotenv::class)) {
        throw new \RuntimeException('APP_ENV environment variable is not defined. You need to define environment variables for configuration or add "symfony/dotenv" as a Composer dependency to load variables from a .env file.');
    }
    (new Dotenv())->load(__DIR__.'/../.env');
}

$env = $_SERVER['APP_ENV'] ?? 'dev';
$debug = $_SERVER['APP_DEBUG'] ?? ('prod' !== $env);

if ($debug) {
    umask(0000);

    Debug::enable();
}

if ($trustedProxies = $_SERVER['TRUSTED_PROXIES'] ?? false) {
    Request::setTrustedProxies(explode(',', $trustedProxies), Request::HEADER_X_FORWARDED_ALL ^ Request::HEADER_X_FORWARDED_HOST);
}

if ($trustedHosts = $_SERVER['TRUSTED_HOSTS'] ?? false) {
    Request::setTrustedHosts(explode(',', $trustedHosts));
}

$kernel = new Kernel($env, $debug);
$request = Request::createFromGlobals();

// Needed for CloudMatic: check if user is remote and redirect to https if not set
$host = $_SERVER['HTTP_HOST'];
if(filter_var($host, FILTER_VALIDATE_IP, FILTER_FLAG_IPV6)) {
    $host = $_SERVER['SERVER_ADDR'];
}
if (stristr($host,':')) { list($host,$port) = explode(':',$host); }
if ((stristr($_SERVER['SERVER_ADDR'], '10.200.201')) && ($_SERVER['SERVER_ADDR'] != $host) && (!isset($_SERVER['HTTP_X_FORWARDED_PROTO']) && !isset($port))) {
    $response = new RedirectResponse('https://'.$host.$_SERVER['REQUEST_URI'],301);
    $response->send();
}

$request->setDefaultLocale('de_DE');

if (substr($_SERVER['REQUEST_URI'],0,6) !== '/admin') {
    if (!stristr($_SERVER['REQUEST_URI'],'/check/') && !stristr($_SERVER['REQUEST_URI'],'/license')) {
        $install = new App\Utils\Installer();
        $install->check($request,$host);
        if (!stristr($_SERVER['REQUEST_URI'],'/login')) {
            $license = new App\Utils\License();
            $license->check($request,1);
        }
    }
} else {
    if (!stristr($_SERVER['REQUEST_URI'],'/check/')) {
        $pwd = new App\Utils\Checkpassword();
        $pwd->check($request);
    }
}

$response = $kernel->handle($request);
$response->send();
$kernel->terminate($request, $response);
