var svg = d3.select("svg"),
    margin = {top: 10, right: 20, bottom: 50, left: 50},
    width = 1024 - margin.left - margin.right,
    height = 450 - margin.top - margin.bottom,
    displayFormat = d3.timeFormat("%H:%M");

// define the background
var gradient = svg.append("defs")
    .append("linearGradient")
    .attr("id", "gradient")
    .attr("x1", "0%")
    .attr("y1", "100%")
    .attr("x2", "0%")
    .attr("y2", "0%")
    .attr("spreadMethod", "pad");
// add colors for gradient background
gradient.append("stop")
    .attr("offset", "0%")
    .attr("stop-color", "#1776b6")
    .attr("stop-opacity", 1);
gradient.append("stop")
    .attr("offset", "50%")
    .attr("stop-color", "#24a222")
    .attr("stop-opacity", 1);
gradient.append("stop")
    .attr("offset", "100%")
    .attr("stop-color", "#d8241f")
    .attr("stop-opacity", 1);

// define the tooltips
var tooltip = d3.select("body")
    .append("div")
    .style("position", "absolute")
    .style("z-index", "10")
    .style("visibility", "hidden")
    .style("background", "#fff")
    .text("");
// x-Axis scale
var x = d3.scaleTime().rangeRound([0, width]);
// y-Axis scale
var y = d3.scaleLinear().rangeRound([height, 0]);
// define x-Axis
var xAxis = d3.axisBottom(x)
    .tickFormat(d3.timeFormat("%H:%M"))
    .ticks(24);
// define y-Axis
var yAxis = d3.axisLeft(y)
    .ticks(5);
// define the line plotting
var line = d3.line()
    .x(function(d) { return x(d[0]); })
    .y(function(d) { return y(d[1]); }).curve(d3.curveStepAfter);
// dragging events
let drag = d3.drag()
    .on('start', dragstarted)
    .on('drag', dragged)
    .on('end', dragended);

// create viewport
svg.append('rect')
    .attr('class', 'zoom')
    .attr('fill', 'none')
    .attr('pointer-events', 'all')
    .attr('width', width)
    .attr('height', height)
    .attr('transform', 'translate(' + margin.left + ',' + margin.top + ')')
    .style("fill", "url(#gradient)");

    
// create actual curve
var heatingCurve = svg.append("g")
    .attr("transform", "translate(" + margin.left + "," + margin.top + ")");

heatingCurve.append("text")         
    .attr('class', 'axis x-axis-description')    
    .attr("transform", "translate(" + (width/2) + " ," + (height + margin.top + 30) + ")")
    .style("text-anchor", "middle");

// add y-Axis description
heatingCurve.append("text")
    .attr('class', 'axis y-axis-description')
    .attr("transform", "rotate(-90)")
    .attr("y", 0 - margin.left)
    .attr("x",0 - (height / 2))
    .attr("dy", "1em")
    .style("text-anchor", "middle");
    
// draw the circles
function drawCircles(data) {
    heatingCurve.selectAll('circle').remove();
    heatingCurve.selectAll('circle')
        .data(data)
        .enter()
        .append('circle')
        .attr('r', 5.0)
        .attr('cx', function(d) { return x(d[0]);  })
        .attr('cy', function(d) { return y(d[1]); })
        .attr('id', function(d, i) { return i; })
        .style('cursor', 'pointer')
        .style('fill', '#1f71b8')
        .on("mouseover", function(d) {
            tooltip.style('top',(d3.event.pageY-40)+"px");
            tooltip.style('left',(d3.event.pageX-40)+"px");
            tooltip.text("Time: "+displayFormat(d[0])+"h\r\nTemp.: "+Math.round(d[1]* 100) / 100+"°C"); 
            return tooltip.style("visibility", "visible");
        })
        .on("mouseout", function(){return tooltip.style("visibility", "hidden");});
    heatingCurve.selectAll('circle').call(drag);
}

function drawLine(data) {
    heatingCurve.selectAll("path.line").remove();
    heatingCurve.append("path")
        .datum(data)
        .attr('class', 'line')
        .attr("fill", "none")
        .attr("stroke", "#ffffff")
        .attr("stroke-linejoin", "round")
        .attr("stroke-linecap", "round")
        .attr("stroke-width", 1.5)
        .attr("d", line);
}
    
// drag functions
function dragstarted(d,i) {
    d3.selectAll('.active').classed('active', false);
    d3.select(this).raise().classed('active', true);
}
function dragged(d) {
    var offsetMin = 0;
    var offsetMax = width;
    var currentId = parseInt(this.id);
    if (currentId != 0) {
        offsetMin = d3.selectAll("circle[id='"+(currentId-1)+"']").attr('cx');
    }
    if (currentId < (d3.selectAll("circle").size() - 1)) {
        offsetMax = d3.selectAll("circle[id='"+(currentId+1)+"']").attr('cx');
    }
    if (currentId > 0 && currentId < (d3.selectAll("circle").size() - 1)) {
        d3.select(this)
        .attr("cx", d.x = round(Math.max(offsetMin, Math.min(offsetMax, d3.event.x)), (width/288)))
        .attr("cy", d.y = round(Math.max(0, Math.min(height, d3.event.y)), height/51));
        d[0] = x.invert(d.x);
        if (currentId == (d3.selectAll("circle").size() - 2)) {
            // this is the last dragable node, so lets move the endpoint, too!
            d3.selectAll("circle[id='"+(currentId+1)+"']").attr("cy", d.y = round(Math.max(0, Math.min(height, d3.event.y)), height/51));
            d3.selectAll("circle[id='"+(currentId+1)+"']")._groups[0][0].__data__[1] = y.invert(d.y);
        }
    } else if (currentId == (d3.selectAll("circle").size() - 1)) {
        // the last node may not be dragged!
        return;
    } else {
        // the first node may only use y-axis
        d3.select(this)
        .attr("cy", d.y = round(Math.max(0, Math.min(height, d3.event.y)), height/51));
    }
    d[1] = y.invert(d.y);
    heatingCurve.select('path.line').attr('d', line);

    tooltip.style('top',(d3.event.pageY-40)+"px");
    tooltip.style('left',(d3.event.pageX-40)+"px");
    tooltip.text("Time: "+displayFormat(d[0])+"h\r\nTemp.: "+Math.round(d[1]* 100) / 100+"°C"); 
}
function dragended(d) {
    //d3.select(this).classed('active', false);
    //console.log(d3.select(this)._groups[0][0].__data__);
}

// helper functions
function round(p, n) {
    return p % n < n / 2 ? p - (p % n) : p + n - (p % n);
}