<?php
Namespace App\Controller\Admin\Inventory;

use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Bundle\FrameworkBundle\Controller\Controller;
use Symfony\Component\Validator\Validation;
use Symfony\Component\Validator\Constraints as Assert;
use App\Model\Admin\HomegearGateway;
use App\Utils\Utils;

class GatewayController extends Controller
{
    public function indexAction(Request $request, HomegearGateway $gateway)
    {
        return $this->render('Admin/Inventory/Gateway/list.html.twig', array(
            'sect' => $request->attributes->get('sect'),
            'gateways' => $gateway->list()
        ));
    }

    public function addAction(Request $request, HomegearGateway $gateway)
    {
        return $this->render('Admin/Inventory/Gateway/add.html.twig', array(
            'sect' => $request->attributes->get('sect'),
            'gateways' => $gateway->listFamilies()
        ));
    }

    public function getTypeAction($familyId, Request $request, HomegearGateway $gateway)
    {
        $types = $gateway->listTypes($familyId);
        return new JsonResponse($types);
    }

    public function searchAction($id, Request $request, HomegearGateway $gateway)
    {
        $result = $gateway->search($id);
        return new JsonResponse($result);
    }

    public function ssdpSearchAction($id, Request $request, HomegearGateway $gateway)
    {
        $result = $gateway->ssdpSearch($id);
        return new JsonResponse($result);
    }

    public function createAction($id, Request $request, HomegearGateway $gateway)
    {
        $params = $request->request->all();
        $result = $gateway->create($id,$params);
        if ($result != null) {
            // we have an error!
            return new JsonResponse($result);
        }
        return $this->redirectToRoute('admin.inventory.gateways',array(),301);
    }

    public function editAction($id, Request $request, HomegearGateway $gateway, Utils $utils)
    {
        $params = $request->query->all();
        return $this->render('Admin/Inventory/Gateway/edit.html.twig', array(
            'sect' => $request->attributes->get('sect'),
            'settings' => $gateway->getSettings($id,$params['gatewayId']),
            'mgmt' => $utils->checkManagementRunning(false)
        ));
    }

    public function deleteAction($id, Request $request, HomegearGateway $gateway)
    {
        $params = $request->query->all();
        $result = $gateway->delete($id,$params['gatewayId']);
        return new JsonResponse(array('success' => 1));
    }

    public function getFormAction($familyId, $typeId, Request $request, HomegearGateway $gateway, Utils $utils)
    {
        $addMethods = $gateway->getSettingParameters($familyId, $typeId);
        return $this->render('Admin/Inventory/Gateway/gateway_form.html.twig', array(
            'familyId' => $familyId,
            'typeId' => $typeId,
            'addMethods' => $addMethods,
            'mgmt' =>$utils->checkManagementRunning(false)
        ));
    }

    public function searchDeviceAction($id, Request $request, HomegearGateway $gateway)
    {
        $result = $gateway->searchDevices($id);
        return new JsonResponse($result);
    }

    public function deviceInfoFileUploadAction($familyId, Request $request, HomegearGateway $gateway)
    {
        $id = $request->request->get('id');
        $file = $request->files->get('infofile');
        if ($file !== null) {
            $gateway->uploaddeviceInfoFile($familyId,$file);
        }
        return $this->redirectToRoute('admin.inventory.gateways.edit',array('id' => $familyId, 'gatewayId' => $id),301);
    }
}