<?php
Namespace App\Model\Admin;

Use App\Utils\Utils;
use Symfony\Component\Translation\TranslatorInterface;

/**
 * Provides admin functions for Homegear Influxdb management
 *
 */
class HomegearInfluxdb
{
    public $hg;
    private $translator;
    private $utils;

    public function __construct(TranslatorInterface $translator, Utils $utils)
    {
        $this->hg = new \Homegear\Homegear;
        $this->utils = $utils;
        $this->translator = $translator;
    }

    /**
     * Get current settings of homegear-influxdb
     * 
     * @return array()
     */
    public function getSettings()
    {
        if ($this->utils->checkManagementRunning(false)) {
            try {
                foreach (['hostname', 'port', 'username', 'password'] as $setting) {
                    $result[$setting] = $this->hg->managementGetConfigurationEntry('influxdb.conf',$setting);
                }
                return $result;
            } catch(\Homegear\HomegearException $e) {
                return ['result' => 'error', 'message' => $e->getMessage()];
            }
        }
        return ['result' => 'error', 'msg' => $this->translator->trans('management.not_running',array(),'admin')];
    }

    /**
     * Update settings of homegear-influxdb
     * 
     * @return array()
     */
    public function updateSettings($params = null)
    {
        if ($params === null || !is_array($params)) { return false; }
        if ($this->utils->checkManagementRunning(false)) {
            foreach (['hostname', 'port', 'username', 'password'] as $setting) {
                if ($setting == 'username' && $params[$setting] == '') { continue; }
                if ($setting == 'password' && $params[$setting] == '') { continue; }
                $this->hg->managementSetConfigurationEntry('influxdb.conf',$setting, $params[$setting]);
            }
            return ['result' => 'success'];
        }
        return ['result' => 'error', 'msg' => $this->translator->trans('influxdb.settings.unable_to_update_settings',array(),'admin')];
    }

    /**
     * Restart homegear-influxdb
     * 
     * @return array()
     */
    public function restartService()
    {
        if ($this->utils->checkManagementRunning(false)) {
            // stop homegear-management
            $stopId = $this->hg->managementServiceCommand('homegear-influxdb','stop');
            $stopResult = $this->utils->getCommandStatus($stopId);
            if ($stopResult['exitCode'] == 0) {
                // stop was successful, start again
                $startId = $this->hg->managementServiceCommand('homegear-influxdb','start');
                $startResult = $this->utils->getCommandStatus($startId);
                if ($startResult['exitCode'] == 0) {
                    return ['result' => 'success', 'msg' => $this->translator->trans('influxdb.settings.update_done',array(),'admin')];
                }
                return ['result' => 'error', 'service' => $service, 'msg' => $this->translator->trans('influxdb.settings.unable_to_start_service',array(),'admin')];
            }
            return ['result' => 'error', 'service' => $service, 'msg' => $this->translator->trans('influxdb.settings.unable_to_stop_service',array(),'admin')];
        }
        return ['result' => 'error', 'msg' => $this->translator->trans('management.not_running',array(),'admin')];
    }
}
