<?php
Namespace App\Model\Admin;

use Symfony\Component\DependencyInjection\ParameterBag\ParameterBagInterface;
use App\Model\HomegearStory as BaseStory;

/**
 * Provides admin functions for Homegear room management
 *
 */
class HomegearStory extends BaseStory
{
    public function __construct(ParameterBagInterface $params)
    {
        parent::__construct($params);
    }

    /**
     * Create a new story
     * 
     * @return int
     */
    public function create($name, $lang = null)
    {
        $data = array();
        if ($lang === null) { 
            $data = [$this->defaultLanguage => $name];
        } else {
            $data = [$this->defaultLanguage => $name, $lang => $name];
        }
        try {
            $newId = $this->hg->createStory($data);
        }
        catch(\Homegear\HomegearException $e) {
            return $e;
        }
        return $newId;
    }

    /**
     * Update a story name
     * 
     * @return none
     */
    public function update($id = null, $name = null)
    {
        if ($id === null || $name === null) { return; }
        if (!is_array($name)) {
            $name = [$this->defaultLanguage => "$name"];
        }
        foreach ($name as $l => $n) {
            if ($name == '') {
                unset($name[$l]);
            }
        }
        // Update name
        $this->hg->updateStory(intval($id),$name);
    }

    /**
     * Delete a story
     * 
     * @return none
     */
    public function delete($id) {
        // delete all rooms in story
        $roomsInStory = $this->hg->getRoomsInStory(intval($id));
        if (count($roomsInStory) > 0) {
            foreach($roomsInStory as $k => $v) {
                $this->hg->removeRoomFromStory(intval($id),intval($v));
            }
        }
        $this->hg->deleteData(parent::componentStoryGridSort,$id);
        // delete story
        $this->hg->deleteStory(intval($id));
    }

    /**
     * Update sorting of stories
     * 
     * @return none
     */
    public function updateSort($id = null, $position = null) {
        if ($id === null || $position === null) { return; }
        $this->hg->setStoryMetadata(intval($id),['position' => intval($position)]);
    }

    /**
     * Adds rooms to a story
     * 
     * @return none
     */
    public function addRoom($id = null, $rooms = null) {
        if ($id === null || $rooms === null)  { return; }
        if (is_array($rooms) && (count($rooms) > 0)) {
            foreach ($rooms as $room) {
                $this->hg->addRoomToStory(intval($id),intval($room));
            }
        }
    }

    /**
     * Remove a room from a story
     */
    public function removeRoom($id = null, $roomId = null) 
    {
        if ($id === null || $roomId === null)  { return; }
        // get sorting of rooms in current story
        $sort = json_decode($this->hg->getData(parent::componentStoryGridSort,"$id"),true);
        // TODO: add this check to all functions using sort-table!
        if ($sort !== null && is_array($sort)) {
            // check if target-device is in sorting-array
            $key = array_search("$roomId",$sort);
            if ($key !== false) {
                // room found, delete it from array and save again
                unset($sort[$key]);
                $this->hg->setData(parent::componentStoryGridSort,$id,json_encode($sort));
            }
        }
        $this->hg->removeRoomFromStory(intval($id),intval($roomId));
    }

    public function updateRoomSort($id = null, $room = null, $position = null) {
        if ($id === null || $room === null || $position === null) { return; }
        // get current sort-data
        $sort = json_decode($this->hg->getData(parent::componentStoryGridSort,"$id"),true);
        // check if target-room is in array already
        if (is_array($sort)) {
            $key = array_search("$room",$sort);
            if ($key !== false) {
                // target-device found, delete it from array
                unset($sort[$key]);
            }
        }
        // set new position
        $sort[$position] = "$room";
        // save new sort-data
        $this->hg->setData(parent::componentStoryGridSort,$id,json_encode($sort));
    }
}