<?php
Namespace App\Model\Admin;

use Symfony\Component\Translation\TranslatorInterface;
Use App\Utils\Utils;

/**
 * Provides admin functions for Homegear update management
 *
 */
class HomegearUpdate
{
    public $hg;
    private $utils;
    private $translator;

    public function __construct(TranslatorInterface $translator, Utils $utils)
    {
        $this->hg = new \Homegear\Homegear;
        $this->utils = $utils;
        $this->translator = $translator;
    }

    /**
     * Manually check for updates
     * 
     * @return array()
     */
    public function check()
    {
        if ($this->utils->checkManagementRunning(false)) {
            $updateAvailable = false;
            $id = $this->hg->managementAptUpdate();
            $result = $this->utils->getCommandStatus($id);
            if ($result['exitCode'] == 0) {
                $updates['System'] = $this->hg->managementSystemUpdateAvailable(); 
                $updates['Homegear'] = $this->hg->managementHomegearUpdateAvailable();
                foreach ($updates as $type => $value) {
                    if ($value && $value != '') {
                        touch("/tmp/update$type.txt");
                        $updateAvailable = true;
                    } else {
                        if (file_exists("/tmp/update$type.txt")) {
                            unlink("/tmp/update$type.txt");
                        }
                    }
                }
                $result = exec('apt list --upgradable 2>/dev/null | grep -c homegear-smarthaui');
                if ($result && intval($result) != 0) {
                    touch("/tmp/updateHomegear.txt");
                    $updateAvailable = true;
                }
                $result1 = exec('apt list --upgradable 2>/dev/null | grep -c homegear-smartha-devicedefinitions');
                if ($result1 && intval($result1) != 0) {
                    touch("/tmp/updateDeviceDefinitions.txt");
                    $updateAvailable = true;
                }
                return ['result' => 'success', 'msg' => (!$updateAvailable ? $this->translator->trans("updates.notfound",array(),'admin') : $this->translator->trans("updates.found",array(),'admin') )];
            }
            return ['result' => 'error', 'msg' => $this->translator->trans('updates.error_checking',array(),'admin')];
        }
        return ['result' => 'error', 'msg' => $this->translator->trans('management.not_running',array(),'admin')];
    }

    /**
     * List all current updates
     * 
     * @return array
     */
    public function list()
    {
        // check if an update is running
        if ($this->utils->checkUpdateRunning('_sys-update-running') === true || $this->utils->checkUpdateRunning('_os-update-running') === true) {
            $os = -1;
            $system = -1;
            $deviceDefinition = -1;
        } else {
            $os = (file_exists('/tmp/updateSystem.txt') ? 1 : 0);
            $system = (file_exists('/tmp/updateHomegear.txt') ? 1 : 0);
            $deviceDefinition = (file_exists('/tmp/updateDeviceDefinitions.txt') ? 1 : 0);
        }
        return ['system' => $system, 'os' => $os, 'device_definition' => $deviceDefinition];
    }

    /**
     * Update packages
     * 
     * @return json
     */
    public function update($type = null)
    {
        if ($type === null) { return ['result' => 'error', 'msg' => 'Update-type missing']; }
        if ($type == 'device_definition') {
            if ($this->utils->checkManagementRunning(false)) {
                $id = $this->hg->managementAptUpgrade(intval(1));
                $this->utils->saveToSession(['_sys-update-running' => $id]);
                return ['result' => 'success'];
            }
        } elseif ($type == 'sys') {
            if ($this->utils->checkManagementRunning(false)) {
                $id = $this->hg->managementAptUpgrade(intval(1));
                $this->utils->saveToSession(['_sys-update-running' => $id]);
                return ['result' => 'success'];
            }
        } elseif ($type == 'os') {
            if ($this->utils->checkManagementRunning(false)) {
                $id = $this->hg->managementAptUpgrade(intval(0));
                $this->utils->saveToSession(['_os-update-running' => $id]);
                return ['result' => 'success'];
            }
        }
        return ['result' => 'error', 'msg' => 'Error getting update'];
    }
}