<?php
Namespace App\Model\Admin;

use Symfony\Component\Translation\TranslatorInterface;
use App\Model\HomegearUser as BaseUser;

/**
 * Provides admin functions for Homegear user management
 *
 */
class HomegearUser extends BaseUser
{
    private $translator;

    public function __construct(TranslatorInterface $translator)
    {
        parent::__construct();
        $this->translator = $translator;
    }

    /**
     * Loads all users
     * 
     * @return array()
     */
    public function loadAll() {
        return $this->hg->listUsers();
    }

    /**
     * Loads all groups
     * 
     * @return array()
     */
    public function loadAllGroups()
    {
        return $this->hg->getGroups();
    }

    /**
     * Loads a specific user by username
     * 
     * @return array()
     */
    public function loadByUsername($username = null, $currentUser = null) {
        if ($this->hg->userExists($username) === true) {
            $user['name'] = $username;
            $user['deleteable'] = (count($this->loadAll()) > 0 ? 1 : 0);
            $user['deleteable'] = ($currentUser == $username ? 0 : 1);
            $user['certificate'] = file_exists('/etc/homegear/ca/certs/'.$username.'.crt');
            $user['groups'] = $this->loadUserGroups($username);
            $settings = $this->loadUserSettings($username);
            if (is_array($settings) && count($settings) > 0) {
                $user['locale'] = (array_key_exists('locale',$settings) ? $settings['locale'] : '');
                $user['theme'] = (array_key_exists('theme',$settings) ? $settings['theme'] : '');
                $user['expert'] = (array_key_exists('expert',$settings) ? $settings['expert'] : '');
            }
            return $user;
        }
    }

    public function updateUser($username = null, $newPassword = null, $groups = array(), $locale = null, $theme = null, $expert = null)
    {
        if ($username === null) { return; }
        $groups = $this->fixGroups($groups);
        if ($newPassword !== null && $newPassword != '') {
            if ($groups !== null && is_array($groups) && count($groups) > 0) {
                $this->hg->updateUser($username, $newPassword, $groups);
            } else {
                $this->updatePassword($username, $newPassword);
            }
        } else {
            try {
                $this->hg->updateUser($username, $groups);
            } catch(\Homegear\HomegearException $e) {
                return "Exception catched. Code: ".$e->getCode().". Message: ".$e->getMessage();
            }
        }
        $settings = $this->loadUserSettings($username);
        $settings['locale'] = $locale;
        $settings['theme'] = $theme;
        $settings['expert'] = $expert;
        $this->hg->setUserMetadata($username,$settings);
    }

    /**
     * Update a user password
     * 
     * @return mixed
     */
    public function updatePassword($username = null, $newPassword = null)
    {
        try {
            if($username == 'homegear' && $newPassword != 'homegear') {
                unset($_SESSION['pwChangeNeeded']);
            }
            
            $result = $this->hg->updateUser("$username","$newPassword");
        } catch(\Homegear\HomegearException $e) {
            return "Exception catched. Code: ".$e->getCode().". Message: ".$e->getMessage();
        }
        return true;
    }

    /**
     * Create a user
     * 
     * @return mixed
     */
    public function create($username = null, $password = null, $groups = array()) {
        $groups = $this->fixGroups($groups);
        try {
            $this->hg->createUser(strtolower($username),$password,$groups);
        } catch(\Homegear\HomegearException $e) {
            return "Exception catched. Code: ".$e->getCode().". Message: ".$e->getMessage();
        }
        return true;
    }

    /**
     * Generate a certificate for a user
     * 
     * @return array
     */
    public function generateCertificate($username = null)
    {
        if ($username === null) { return; }
        try {
            $this->hg->managementCreateCert(strtolower($username));
        } catch(\Homegear\HomegearException $e) {
            return ['result' => 'error', 'message' => $this->translator->trans('ajax.exception.user.certificate.'.$e->getMessage(),array(),'admin')];
        }
        return ['result' => 'success'];
    }

    /**
     * Delete a user
     * 
     * @return mixed
     */
    public function delete($username = null)
    {
        try {
            $this->hg->deleteUser($username);
            $this->hg->managementDeleteCert($username);
        } catch(\Homegear\HomegearException $e) {
            return "Exception catched. Code: ".$e->getCode().". Message: ".$e->getMessage();
        }
        return true;
    }

    /**
     * Fix array-values (convert to int)
     * 
     * @return array()
     */
    private function fixGroups($groups = null)
    {
        if ($groups === null) { return; }
        // *sic* convert groupIds to int ... HTTP-POST is sending strings
        if (is_array($groups)) {
            foreach ($groups as $key => $value) { $groups[$key] = intval($value); }
        }
        return $groups;
    }
}