<?php
Namespace App\Model;

use Symfony\Component\HttpFoundation\RequestStack;
use Symfony\Component\Routing\RouterInterface;

/**
 * Provides base functions for Homegear devices
 *
 */
class HomegearDevice
{
    public $hg;
    protected $requestStack;
    protected $router;

    public function __construct(RequestStack $requestStack, RouterInterface $router)
    {
        $this->hg = new \Homegear\Homegear;
        $this->requestStack = $requestStack;
        $this->router = $router;
    }

    /**
     * Loads all paired devices
     * 
     * @return array()
     */
    public function loadAll() {
        $devices = array();
        $families = $this->_loadFamilyNames();
        $devicesRaw = $this->hg->listDevices(false,array("FAMILY", "ID", "ADDRESS", "TYPE", "FIRMWARE", "INTERFACE", "IP_ADDRESS", "NAME"));
        foreach($devicesRaw as $value) {
            $gateway = $this->hg->getDeviceInfo($value["ID"],array("INTERFACE"));
            $devices[] = array("ID" => $value["ID"], "unreach" => (isset($value["UNREACH"]) ? $value["UNREACH"] : ''), "name" => $value['NAME'], "family" => $families[$value["FAMILY"]], "address" => $value["ADDRESS"], "type" => $value["TYPE"], "interface" => $value["INTERFACE"], "firmware" => ($value["FIRMWARE"] != "?" ? $value["FIRMWARE"] : "n/a"), "gateway" => (array_key_exists('INTERFACE',$gateway) ? $gateway['INTERFACE'] : "n/a"));
        }
        // sort by homegear-id
        usort($devices, function($a, $b) { return $a['ID'] <=> $b['ID']; });
        return $devices;
    }

    /**
     * Helper function
     * TODO: refactor in seperate helper-class
     * 
     * @return integer;
     */
    public function multidimensional_search($parents, $searched) {
        if (empty($searched) || empty($parents)) { return false; }
        foreach ($parents as $key => $value) {
            $exists = true;
            foreach ($searched as $skey => $svalue) {
            $exists = ($exists && IsSet($parents[$key][$skey]) && $parents[$key][$skey] == $svalue);
            }
            if($exists){ return $key; }
        }
        return -1;
    }

    /**
     * Load all known family names
     * 
     * @return array()
     */
    public function _loadFamilyNames() {
        $families = $this->hg->listFamilies();
        $familyNames = array();
        foreach($families as $value) {
            $familyNames[$value["ID"]] = $value["NAME"];
        }
        return $familyNames;
    }

}