<?php
Namespace App\Model;

/**
 * Provides base functions for Homegear groups
 *
 */
class HomegearGroup
{
    const componentGroupSort = 'sortGroups';
    const componentGroupGridSort = 'sortGroupsGrid';
    public $hg;
    public $defaultLanguage;

    public function __construct($params)
    {
        $this->hg = new \Homegear\Homegear;
        $this->defaultLanguage = $params->get('default_locale');
    }

    /**
     * Load all groups
     * 
     * @return array()
     */
    public function loadAll()
    {
        // load all groups, return if there are none
        try {
            $groups = $this->hg->getCategories();
        } catch(\Homegear\HomegearException $e) {
            return;
        }
        if (is_array($groups) && count($groups) == 0) { return; }
        // DEPRECATED: sorting is done by homegear directly!
        $groups = $this->_sortGroups($groups);
        return $groups;
    }

    public function loadById($id = null)
    {
        $allGroups = $this->loadAll();
        if ($id === null) { 
            // no id given, try to load first room
            if (is_array($allGroups) && count($allGroups) > 0) {
                $id = $allGroups[0]['ID'];
            }
        }
        if ($id !== null) {
            // get the room metadata out of the group-array
            $result = $allGroups[array_search($id, array_column($allGroups,'ID'))];
            // load sorting
            $sort = json_decode($this->hg->getData($this::componentGroupGridSort,$id),true);
            // load devices
            $devices = $this->hg->getDevicesInCategory(intval($id));
            $channels = $this->hg->getChannelsInCategory(intval($id));
            $variables = $this->hg->getVariablesInCategory(intval($id));
            $systemVariables = $this->hg->getSystemVariablesInCategory(intval($id));
            foreach ($devices as $device) {
                $result['devices'][] = ['ID' => $device, 'channel' => '-1', 'variable' => ''];
            }
            foreach ($channels as $device => $data) {
                foreach ($data as $key => $channel) {
                    if ($channel == -1) { continue; }
                    $result['devices'][] = ['ID' => $device, 'channel' => $channel, 'variable' => ''];
                }
            }
            foreach ($variables as $device => $value) {
                foreach ($value as $channel => $data) {
                    if ($channel == -1) { continue; }
                    foreach ($data as $key => $variable) {
                        $result['devices'][] = ['ID' => $device, 'channel' => $channel, 'variable' => $variable];
                    }
                }
            }
            foreach ($systemVariables as $device) {
                $result['devices'][] = ['ID' => 'systemVariable', 'channel' => '', 'variable' => $device, 'name' => $device];
            }
            if (array_key_exists('devices',$result)) {
                foreach ($result['devices'] as $k => $v) {
                    $key = 0;
                    if (is_array($sort) && count($sort) > 0) {
                        $key = array_search($v['ID']."-".$v['channel']."-".$v['variable'], $sort);
                    }
                    $v['sort'] = (isset($key) ? $key : 0);
                    $result['devices'][$k] = $v;
                }
                $result['devices'] = ((is_array($result['devices']) && count($result['devices']) > 0) ? array_values($result['devices']) : null);
            }
            return $result;
        }
    }

    /**
     * Sort groups
     * 
     * DEPRECATED: sorting is done by homegear directly!
     * This is only needed once to convert from db-style to homegear-style
     * @return array()
     */
    private function _sortGroups($groups = null) {
        if ($groups === null) { return; }
        // load sorting data
        $sort = $this->hg->getData($this::componentGroupSort);
        if ($sort !== null) {
            foreach ($groups as $group) {
                if (array_key_exists($group['ID'],$sort)) {
                    $this->hg->setCategoryMetadata($room['ID'],['position' => intval($sort[$group['ID']])]);
                }
            }
            $groups = $this->sortDataByComponent($groups,$sort);
            // delete sorting data since it's not needed anymore
            $this->hg->deleteData($this::componentGroupSort);
        }
        return $groups;
    }

    /**
     * DEPRECATED: sorting is done by homegear directly!
     * 
     */
    private function sortDataByComponent($dataToSort,$component)
    {
        foreach ($dataToSort as $k => $v) {
            $dataToSort[$k]['sort'] = (isset($component[$v['ID']]) ? $component[$v['ID']] : 0);
        }
        usort($dataToSort, function($a, $b) {
            $retval = $a['sort'] <=> $b['sort'];
            if ($retval == 0) { $retval = $a['ID'] <=> $b['ID']; }
            return $retval;
        });
        return $dataToSort;
    }

}