<?php
namespace App\Security\User;

use App\Security\User\HomegearUser;
use Symfony\Component\Security\Core\User\UserProviderInterface;
use Symfony\Component\Security\Core\User\UserInterface;
use Symfony\Component\Security\Core\Exception\UsernameNotFoundException;
use Symfony\Component\Security\Core\Exception\UnsupportedUserException;

class HomegearUserProvider implements UserProviderInterface
{
    public function loadUserByUsername($username)
    {
        // make a call to your webservice here
        $hg = new \Homegear\Homegear;
        $userData = $hg->userExists($username);
        // pretend it returns an array on success, false if there is no user
        
        if ($userData) {
            $password = '';
            $locale = $this->getLocale($hg,$username);
            $roles = array('ROLE_ADMIN');
            if($hg->setUserPrivileges($username) === false)
                {
                    die("FEHLER");
                }
            return new HomegearUser($username, $password, $locale, $roles);
        }

        throw new UsernameNotFoundException(
            sprintf('Username "%s" does not exist.', $username)
        );
    }

    public function refreshUser(UserInterface $user)
    {
        if (!$user instanceof HomegearUser) {
            throw new UnsupportedUserException(
                sprintf('Instances of "%s" are not supported.', get_class($user))
            );
        }
        $username = $user->getUsername();
        $hg = new \Homegear\Homegear;
        if($hg->setUserPrivileges($username) === false) {
            throw new UnsupportedUserException(sprintf('Unable to setUserPrivileges for user "%s"', $username));
        }
        return $user;
    }

    public function supportsClass($class)
    {
        return HomegearUser::class === $class;
    }

    private function getLocale($hg,$username)
    {
        try {
            $settings = $hg->getUserMetadata($username);
            return (array_key_exists('locale',$settings) ? $settings['locale'] : 'de-DE');
        } catch(\Homegear\HomegearException $e) {
            return 'de-DE';
        }
    }
}